@@ -21,6 +21,7 @@ import numpy as np
 from pathlib import Path
 import requests
 from tqdm import tqdm
+import tarfile
 
 from ucr.inference.torch import predict_system
 from ucr.utils.logging import get_logger
@@ -35,210 +36,206 @@ model_urls = {
         'det': {
             'DB': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_server/ench_ppocr_server_det.pt',
-                'config_path': '../configs/det/det_ench_ppocr_server.yml'
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_server/det_ench_ppocr_server.tar'
             },
             'CRAFT': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_server/det_vgg_craft.pt',
-                'config_path': '../configs/det/det_vgg_craft.yml'
-            }
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_server/det_vgg_craft.tar'
+            }    
         },
         'rec': {
             'ch_sim': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_server/ench_ppocr_server_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_server/rec_ench_ppocr_server.tar',
                 'dict_path': './utils/dict/ench_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_ench_ppocr_server.yml'
+                
             }
         }
     },
 
-    'torch_lite': {
+    'torch_mobile': {
         'det': {
             'DB': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/ench_ppocr_mobile_det.pt',
-                'config_path': '../configs/det/det_ench_ppocr_mobile.yml'
-            }
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/det_ench_ppocr_mobile.tar',
+            }  
         },
         'rec': {
             'ch_sim': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/ench_ppocr_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ench_ppocr_mobile.tar',
                 'dict_path': './utils/dict/ench_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_ench_ppocr_mobile.yml'
+                
             },
             'en': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/rec_en_number_lite.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_en_number_mobile.tar',
                 'dict_path': './utils/dict/en_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_en_number_lite.yml'
+                
             },
             'fr': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/french_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_french_mobile.tar',
                 'dict_path': './utils/dict/french_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_french_lite.yml'
+                
             },
             'de': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/german_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_german_mobile.tar',
                 'dict_path': './utils/dict/german_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_german_lite.yml'
+                
             },
             'ko': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/korean_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_korean_mobile.tar',
                 'dict_path': './utils/dict/korean_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_korean_lite.yml'
+                
             },
             'ja': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/japan_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_japan_mobile.tar',
                 'dict_path': './utils/dict/japan_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_japan_lite.yml'
+                
             },
             'ch_tra': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/chinese_cht_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_chinese_cht_mobile.tar',
                 'dict_path': './utils/dict/chinese_cht_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_chinese_cht_lite.yml'
+                
             },
             'it': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/it_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_it_mobile.tar',
                 'dict_path': './utils/dict/it_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_it_lite.yml'
+                
             },
             'es': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/xi_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_xi_mobile.tar',
                 'dict_path': './utils/dict/xi_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_xi_lite.yml'
+                
             },
             'pt': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/pu_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_pu_mobile.tar',
                 'dict_path': './utils/dict/pu_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_pu_lite.yml'
+                
             },
             'ru': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/ru_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ru_mobile.tar',
                 'dict_path': './utils/dict/ru_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_ru_lite.yml'
+                
             },
             'ar': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/ar_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ar_mobile.tar',
                 'dict_path': './utils/dict/ar_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_ar_lite.yml'
+                
             },
             'hi': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/hi_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_hi_mobile.tar',
                 'dict_path': './utils/dict/hi_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_hi_lite.yml'
+                
             },
             'ug': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/ug_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ug_mobile.tar',
                 'dict_path': './utils/dict/ug_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_ug_lite.yml'
+                
             },
             'fa': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/fa_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_fa_mobile.tar',
                 'dict_path': './utils/dict/fa_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_fa_lite.yml'
+                
             },
             'ur': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/ur_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ur_mobile.tar',
                 'dict_path': './utils/dict/ur_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_ur_lite.yml'
+                
             },
             'rs_latin': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/rs_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_rs_mobile.tar',
                 'dict_path': './utils/dict/rs_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_rs_lite.yml'
+                
             },
             'oc': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/oc_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_oc_mobile.tar',
                 'dict_path': './utils/dict/oc_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_oc_lite.yml'
+                
             },
             'mr': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/mr_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_mr_mobile.tar',
                 'dict_path': './utils/dict/mr_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_mr_lite.yml'
+                
             },
             'ne': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/ne_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ne_mobile.tar',
                 'dict_path': './utils/dict/ne_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_ne_lite.yml'
+                
             },
             'rs_cyrillic': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/rsc_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_rsc_mobile.tar',
                 'dict_path': './utils/dict/rsc_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_rsc_lite.yml'
+                
             },
             'bg': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/bg_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_bg_mobile.tar',
                 'dict_path': './utils/dict/bg_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_bg_lite.yml'
+                
             },
             'uk': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/uk_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_uk_mobile.tar',
                 'dict_path': './utils/dict/uk_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_uk_lite.yml'
+                
             },
             'be': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/be_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_be_mobile.tar',
                 'dict_path': './utils/dict/be_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_be_lite.yml'
+                
             },
             'te': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/te_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_te_mobile.tar',
                 'dict_path': './utils/dict/te_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_te_lite.yml'
+                
             },
             'kn': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/ka_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ka_mobile.tar',
                 'dict_path': './utils/dict/ka_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_ka_lite.yml'
+                
             },
             'ta': {
                 'url':
-                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/ta_mobile_rec.pt',
+                'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ta_mobile.tar',
                 'dict_path': './utils/dict/ta_dict.txt',
-                'config_path': '../configs/rec/multi_language/rec_ta_lite.yml'
+                
             }
         },
         'cls': {
             'url':
-            'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_lite/ench_ppocr_mobile_cls.pt',
-            'config_path': '../configs/cls/cls_ench_ppocr_mobile.yml'
+            'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/cls_ench_ppocr_mobile.tar'
         }
     }
 }
 
 
 SUPPORT_DET_MODEL = ['DB', 'CRAFT']
-SUPPORT_REC_MODEL = ['CRNN']
+SUPPORT_MODEL = ['CRNN']
 VERSION = 1.0
-SUPPORT_MODEL_TYPE = ['torch_lite', 'torch_server', 'onnx_lite', 'onnx_server']
+SUPPORT_MODEL_TYPE = ['torch_mobile', 'torch_server', 'onnx_mobile', 'onnx_server']
 BASE_DIR = os.path.expanduser("~/.ucr/")
 
 
@@ -259,16 +256,23 @@ def download_with_progressbar(url, save_path):
 
 def maybe_download(model_storage_directory, url):
     # using custom model
-    model = url.split('/')[-1]
-    path = os.path.join(model_storage_directory, model)
-    if not os.path.exists(
-            os.path.join(model_storage_directory, model)
-    ):
-        logger.info('Downloading {} to {}'.format(url, path))
-        os.makedirs(model_storage_directory, exist_ok=True)
-        download_with_progressbar(url, path)
     
-    return path
+    fname = url.split('/')[-1][0:-4]
+    tmp_path = os.path.join(model_storage_directory, fname)
+    if not os.path.exists(
+            os.path.join(tmp_path, fname+'.pt')
+    ) or not os.path.exists(
+            os.path.join(tmp_path, fname+'.yml')):
+    
+        logger.info('Downloading {} to {}'.format(url, tmp_path))
+        os.makedirs(tmp_path, exist_ok=True)
+        download_with_progressbar(url, tmp_path+'.tar')
+        
+        with tarfile.open(tmp_path+'.tar', 'r') as tarObj:
+            tarObj.extractall(path=tmp_path, members=tarObj)
+        os.remove(tmp_path+'.tar')
+        
+    return [os.path.join(tmp_path, fname+'.pt'), os.path.join(tmp_path, fname+'.yml')]
 
 def parse_args(mMain=True, add_help=True):
     import argparse
@@ -359,7 +363,7 @@ def parse_args(mMain=True, add_help=True):
         parser.add_argument("--merge_add_margin", type=float, default=0.05)  
         
         parser.add_argument("--lang", type=str, default='ch_sim')
-        parser.add_argument("--model_type", type=str, default='torch_lite')
+        parser.add_argument("--model_type", type=str, default='torch_mobile')
         parser.add_argument("--det", type=str2bool, default=True)
         parser.add_argument("--rec", type=str2bool, default=True)
         parser.add_argument("--use_angle_cls", type=str2bool, default=False)
@@ -416,7 +420,7 @@ def parse_args(mMain=True, add_help=True):
             merge_width_thresh = 2.0,
             merge_add_margin = 0.05,
             lang='ch_sim',
-            model_type='torch_lite',
+            model_type='torch_mobile',
             det=True,
             rec=True,
             use_angle_cls=False)
@@ -440,71 +444,57 @@ class UCR(predict_system.TextSystem):
         if det_algorithm not in SUPPORT_DET_MODEL:
             logger.error('det_algorithm must in {}'.format(SUPPORT_DET_MODEL))
             sys.exit(0)
-        if rec_algorithm not in SUPPORT_REC_MODEL:
-            logger.error('rec_algorithm must in {}'.format(SUPPORT_REC_MODEL))
+        if rec_algorithm not in SUPPORT_MODEL:
+            logger.error('rec_algorithm must in {}'.format(SUPPORT_MODEL))
             sys.exit(0)
         
         assert model_type in SUPPORT_MODEL_TYPE, 'MODEL TYPE must be of {} format, but got {}'.format(
                 SUPPORT_MODEL_TYPE, model_type)
-        
-        if postprocess_params.cls_config_location is None:
-            postprocess_params.cls_config_location = model_urls['torch_lite']['cls'][
-                'config_path']
-        
-        if postprocess_params.det_config_location is None:
-            model_type = 'torch_server' if det_algorithm == 'CRAFT' else model_type
-            postprocess_params.det_config_location = model_urls[model_type]['det'][det_algorithm]['config_path']
-            model_type = postprocess_params.model_type
-        if postprocess_params.rec_config_location is None:
-            model_type = 'torch_lite' if lang != 'ch_sim' else model_type
-            assert lang in model_urls[model_type][
-                'rec'], 'param lang must in {}, but got {}'.format(
-                    model_urls[model_type]['rec'].keys(), lang)
-            postprocess_params.rec_config_location = model_urls[model_type]['rec'][lang][
-                'config_path']
-            model_type = postprocess_params.model_type
+
             
         if postprocess_params.rec_char_dict_path is None:            
-            model_type = 'torch_lite' if lang != 'ch_sim' else model_type
+            model_type = 'torch_mobile' if lang != 'ch_sim' else model_type
             postprocess_params.rec_char_dict_path = model_urls[model_type]['rec'][lang][
                 'dict_path']
             model_type = postprocess_params.model_type
         
         # download model
         model_type = 'torch_server' if det_algorithm == 'CRAFT' else model_type
-        det_path = maybe_download(os.path.join(BASE_DIR, '{}/det'.format(VERSION)), model_urls[model_type]['det'][det_algorithm]['url'])
+        det_path, det_cfg_path = maybe_download(os.path.join(BASE_DIR, '{}/det'.format(VERSION)), model_urls[model_type]['det'][det_algorithm]['url'])
         model_type = postprocess_params.model_type
         
-        model_type = 'torch_lite' if lang != 'ch_sim' else model_type
-        rec_path = maybe_download(os.path.join(BASE_DIR, '{}/rec/{}'.format(VERSION, lang)),
+        model_type = 'torch_mobile' if lang != 'ch_sim' else model_type
+        rec_path, rec_cfg_path = maybe_download(os.path.join(BASE_DIR, '{}/rec/{}'.format(VERSION, lang)),
                        model_urls[model_type]['rec'][lang]['url'])
         model_type = postprocess_params.model_type
         
-        cls_path = maybe_download(os.path.join(BASE_DIR, '{}/cls'.format(VERSION)), model_urls['torch_lite']['cls']['url'])
+        cls_path, cls_cfg_path = maybe_download(os.path.join(BASE_DIR, '{}/cls'.format(VERSION)), model_urls['torch_mobile']['cls']['url'])
         
         # init model dir
         if postprocess_params.det_model_location is None:
             postprocess_params.det_model_location = det_path
+            postprocess_params.det_config_location = det_cfg_path
         if postprocess_params.rec_model_location is None:
             postprocess_params.rec_model_location = rec_path
+            postprocess_params.rec_config_location = rec_cfg_path
         if postprocess_params.cls_model_location is None:
             postprocess_params.cls_model_location = cls_path
+            postprocess_params.cls_config_location = cls_cfg_path
         
         
         postprocess_params.rec_char_dict_path = str(
             Path(__file__).parent / postprocess_params.rec_char_dict_path)
         
-        postprocess_params.cls_config_location = str(
-            Path(__file__).parent / postprocess_params.cls_config_location)
-        postprocess_params.det_config_location = str(
-            Path(__file__).parent / postprocess_params.det_config_location)
-        postprocess_params.rec_config_location = str(
-            Path(__file__).parent / postprocess_params.rec_config_location)
+        # postprocess_params.cls_config_location = str(
+        #     Path(__file__).parent / postprocess_params.cls_config_location)
+        # postprocess_params.det_config_location = str(
+        #     Path(__file__).parent / postprocess_params.det_config_location)
+        # postprocess_params.rec_config_location = str(
+        #     Path(__file__).parent / postprocess_params.rec_config_location)
 
-        # init det_model and rec_model
         super().__init__(postprocess_params)
 
-    def ocr(self, img, det=True, rec=True):
+    def predict(self, img, det=True, rec=True):
         """
         ocr with paddleocr
         args：
